@@ -35,7 +35,10 @@ class LocalDiskBackend(BaseStorageBackend):
 
     def push(self, src, path):
         """Copies local absolute path `src` to remote `path`."""
-        shutil.copy2(src, self.storage_path(path))
+        dst = self.storage_path(path)
+        if not os.path.exists(os.path.dirname(dst)):
+            os.makedirs(os.path.dirname(dst))
+        shutil.copy2(src, dst)
 
 
 StorageBackend = LocalDiskBackend
