@@ -31,6 +31,14 @@ class LocalDiskBackendTestCase(unittest.TestCase):
             pass
         self.assertTrue(f.is_closed())
 
+    def test_push_to_nonexisting_directory(self):
+        dst = '%s/%s' % (bytes.hex(os.urandom(8)), bytes.hex(os.urandom(8)))
+        with tempfile.NamedTemporaryFile() as f:
+            f.write(b"Hello world!")
+            f.flush()
+
+            self.backend.push(f.name, dst)
+
     def test_write_file_with_context(self):
         src = 'foo'
         with self.backend.open(src, 'w') as f:
